import datetime
import os
from logging import *
import logging.config

from .filter import HostAddressFilter, RequestAddressFilter, ConcurrentIdFilter
from .weather import weather_report

__all__ = ["logging"]

# new logging level REPORT
REPORT = 100
logging.addLevelName(REPORT, "REPORT")
log_dir = "/data/log/flask/"


def logger_report(self, msg: str, weather: bool = False, *args, **kwargs):
    """
    Report level for logger, support report weather

    :param msg: dict, report content
    :param weather: bool, report to whether, default is False
    """
    if self.isEnabledFor(REPORT):
        self._log(REPORT, msg, args, **kwargs)
    if weather is True:
        weather_report()


logging.Logger.report = logger_report

logging_config = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "winhye": {
            "format": "[%(asctime)s] <host=%(hostname)s source=%(source_ip)s> %(filename)s line:%(lineno)d <process=%(process)d concurrent=%(concurrent_id)d> [%(levelname)s] %(name)s: %(message)s"
        }
    },
    "filters": {
        "hostname": {
            "()": HostAddressFilter
        },
        "source_ip": {
            "()": RequestAddressFilter
        },
        "concurrent_id": {
            "()": ConcurrentIdFilter
        }
    },
    "handlers": {
        "console": {
            "class": "logging.StreamHandler",
            "level": "DEBUG",
            "formatter": "winhye",
            "filters": ["hostname", "source_ip", "concurrent_id"]
        },
        "file": {
            "class": "logging.handlers.TimedRotatingFileHandler",
            "filename": os.path.join(log_dir, "log.log"),
            "formatter": "winhye",
            "filters": ["hostname", "source_ip", "concurrent_id"],
            "when": "H",
            "interval": 1,
            "backupCount": 168,
            "atTime": datetime.datetime.now(),
            "delay": False
        }
    },
    "loggers": {
        "": {
            "level": "DEBUG",  # logger日志输出级别
            "handlers": ["console", "file"],
        },
        "gunicorn.error": {
            "level": "INFO",
            "handlers": ["file"],
            "propagate": True,
            "qualname": "gunicorn.error"
        },
        "gunicorn.access": {
            "level": "INFO",
            "handlers": ["file"],
            "propagate": True,
            "qualname": "gunicorn.access"
        },
    }
}

# 新建log目录
if not os.path.exists(log_dir):
    os.makedirs(log_dir)

logging.config.dictConfig(logging_config)



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
# 阿里云短信  todo 未测试
import sys
import json
from typing import List

from alibabacloud_dysmsapi20170525.client import Client as Dysmsapi20170525Client
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_dysmsapi20170525 import models as dysmsapi_20170525_models


class Sample:
    def __init__(self):
        pass

    @staticmethod
    def create_client(access_key_id: str, access_key_secret: str, ) -> Dysmsapi20170525Client:
        """
        使用AK&SK初始化账号Client
        @param access_key_id:
        @param access_key_secret:
        @return: Client
        @throws Exception
        """
        config = open_api_models.Config(
            # 您的AccessKey ID,
            access_key_id=access_key_id,
            # 您的AccessKey Secret,
            access_key_secret=access_key_secret
        )
        # 访问的域名
        config.endpoint = 'dysmsapi.aliyuncs.com'
        return Dysmsapi20170525Client(config)

    # 同步发送
    @staticmethod
    def main(args: List[str], ) -> None:
        # 分别为 AccessKey ID AccessKey Secret
        client = Sample.create_client('LTAI5tG9WoZ4CQpdfEHhfVCb', 'FuOX7YpIG3sqPVENmb6ryYdhFubVJl')
        send_sms_request = dysmsapi_20170525_models.SendSmsRequest(
            phone_numbers="13032643571",  # 要发送的手机号  必填
            sign_name="北京云汉通航科技有限公司",  # 短信签名名称  必填
            template_code="SMS_223060267",  # 短信模板ID  必填
            template_param='{"code":"1111"}',  # 短信模板变量对应的实际值
            # sms_up_extend_code='',  # 上行短信扩展码
            # out_id=''  # 外部流水扩展字段
        )
        # 复制代码运行请自行打印 API 的返回值
        result = client.send_sms(send_sms_request)
        print(result)

    # 异步发送
    @staticmethod
    async def main_async(args: List[str], ) -> None:
        # 分别为 AccessKey ID AccessKey Secret
        client = Sample.create_client('LTAI5tG9WoZ4CQpdfEHhfVCb', 'FuOX7YpIG3sqPVENmb6ryYdhFubVJl')
        send_sms_request = dysmsapi_20170525_models.SendSmsRequest(
            phone_numbers="13032643571",  # 要发送的手机号  必填
            sign_name="验证码短信",  # 短信签名名称  必填
            template_code="SMS_223060267",  # 短信模板ID  必填
            template_param='{"code":"1111"}',  # 短信模板变量对应的实际值
            # sms_up_extend_code='',  # 上行短信扩展码
            # out_id=''  # 外部流水扩展字段
        )
        # 复制代码运行请自行打印 API 的返回值
        await client.send_sms_async(send_sms_request)


if __name__ == '__main__':
    Sample.main([])



import os
import sys

PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)

from src.winhye_common.utils.oss_base import OssBucket


def test_oss():
    oss_config = {
        "AccessKey_ID": "LTAI5tFbpMr1R4CVCbUePMWy",
        "AccessKey_Secret": "MJ2WWUbIKDg4UY5EbEsgQ983Lkfwff",
        "endpoint": "oss-cn-beijing.aliyuncs.com",
        "bucket_name": "winhye-kaifa"
    }
    oss_conn = OssBucket(
        oss_config["AccessKey_ID"],
        oss_config["AccessKey_Secret"],
        oss_config["endpoint"],
        oss_config["bucket_name"]
    )
    # url = oss_conn.upload_from_file("123.txt", "123.txt")
    oss_conn.del_file("123.txt")


if __name__ == '__main__':
    test_oss()



import oss2

from winhye_common.utils.exception_base import WinhyeException, ExceptionCode
from winhye_common.winhye_logger import logging as logging

__all__ = ["OssBucket", "OSSException"]
logger = logging.getLogger()


class OSSException(WinhyeException):
    """OSS exception
    """

    def __init__(self, message: str):
        super(OSSException, self).__init__(ExceptionCode.OSS, message)


class OssBucket:
    def __init__(self, access_key_id: str, access_key_secret: str, endpoint: str, bucket_name: str):
        """
        初始化oss链接
        :param access_key_id:  yourAccessKeyId，阿里云账号生成
        :param access_key_secret:  yourAccessKeySecret， 阿里云账号生成
        :param endpoint:  yourEndpoint，地域，北京为例：oss-cn-beijing.aliyuncs.com
        :param bucket_name:  Bucket名称，请查看阿里云桶名称
        """
        auth = oss2.Auth(access_key_id, access_key_secret)
        self.oss_bucket = oss2.Bucket(auth, endpoint, bucket_name, connect_timeout=30)

    def upload(self, oss_path, data):
        """
        二进制流、字符串上传
        :param oss_path: 文件在oss的存储路径
        :param data: 上传的文件内容
        :return:
        """
        retry_count = 0
        while True:
            try:
                retry_count += 1
                row = self.oss_bucket.put_object(oss_path, data)
                logger.debug(f"status: {row.status}")
                if row.status == 200:
                    break
            except Exception as e:
                if retry_count >= 3:
                    logger.error(e)
                    raise OSSException("cannot upload data, status: {exception}".format(exception=e))

    def upload_from_file(self, oss_path: str, local_path: str):
        """
        本地文件上传
        :param oss_path: 文件在oss的存储路径
        :param local_path: 文件的本地路径
        :return:
        """
        retry_count = 0
        while True:
            try:
                retry_count += 1
                row = self.oss_bucket.put_object_from_file(oss_path, local_path)
                logger.debug(f"status: {row.status}")
                if row.status == 200:
                    break
            except Exception as e:
                if retry_count >= 3:
                    logger.error(e)
                    raise OSSException("cannot upload file, status: {exception}".format(exception=e))

    def get_message(self, oss_path: str) -> str:
        """
        获取文件内容
        :param oss_path: 文件在oss的存储路径
        :return: object_stream 文件流文本
        """
        try:
            object_stream = self.oss_bucket.get_object(oss_path).read()
            return object_stream
        except Exception as e:
            logger.error(e)
            raise OSSException("cannot get message, status: {exception}".format(exception=e))

    def get_url(self, oss_path: str, method="GET", expires=5 * 60, slash_safe=True, headers=None, params=None) -> str:
        try:
            url = self.oss_bucket.sign_url(
                method,
                oss_path,
                expires,
                slash_safe=slash_safe,
                headers=headers,
                params=params
            )
            return url
        except Exception as e:
            logger.error(e)
            raise OSSException("cannot get url, status: {exception}".format(exception=e))

    def del_file(self, oss_path: str):
        """
        :param oss_path: 文件在oss的存储路径
        :return:
        """
        retry_count = 0
        while True:
            try:
                retry_count += 1
                row = self.oss_bucket.delete_object(oss_path)
                logger.debug(f"status: {row.status}")
                if row.status == 204:
                    break
            except Exception as e:
                if retry_count >= 3:
                    logger.error(e)
                    raise OSSException("cannot delete file, status: {exception}".format(exception=e))


if __name__ == '__main__':
    oss_conn = OssBucket(
        "LTAI5t99asZVXSnhnm3vSnaq",
        "3tnIF5zEiS90TC1Xgc6cK1Ecab3Ij8",
        "oss-cn-beijing.aliyuncs.com",
        "winhye-test"
    )
    # obj = oss_conn.upload("a/1627464446637.mp3", "1627464446637.mp3")
    obj = oss_conn.get_message("a/1627464446637.mp3")
    print(obj)



import os
import sys
import time

PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)

from src.winhye_common.mqtt.mqtt_base import MqttClint, MqttSendMessageException


def mqtt_test():
    mqtt_config = {
        "broker": "mqtt-cn-i7m2ceaxt07.mqtt.aliyuncs.com",
        "port": 1883,
        "topic": "reported_kaifa/AGV-S/#",
        "AccessKey_ID": "LTAI5tFbpMr1R4CVCbUePMWy",
        "AccessKey_Secret": "MJ2WWUbIKDg4UY5EbEsgQ983Lkfwff",
        "instance_id": "mqtt-cn-i7m2ceaxt07",
        "group_id": "GID_kaifa"
    }
    data = {
        "type": 1,
        "code": 200,
        "payload": {
            "id": "E41203294",
            "armed": "arm"
        }
    }
    handler = MqttClint(mqtt_config)
    time.sleep(1)
    try:
        while True:
            handler.send_message("send_kaifa/AGV-S/aa", data)
            time.sleep(60)
    except MqttSendMessageException:
        print(111111111111111111)


if __name__ == '__main__':
    mqtt_test()



import threading
from sqlalchemy import create_engine, text
from sqlalchemy.orm import sessionmaker

from winhye_common.utils.exception_base import WinhyeException, ExceptionCode
from winhye_common.winhye_logger import logging as logging


__all__ = ['DatabaseClient', 'DBException']
_lock = threading.RLock()
logger = logging.getLogger()


def _acquire_lock():
    if _lock:
        _lock.acquire()


def _release_lock():
    if _lock:
        _lock.release()


class DBException(WinhyeException):
    """DB exception
    """

    def __init__(self, message: str):
        super(DBException, self).__init__(ExceptionCode.DB, message)


class DatabaseClient:
    engines = None
    pool_size = None

    @staticmethod
    def init(pool_size: int = 1):
        """
        Initialize database client

        :param pool_size: int, default value: 1
        """
        if DatabaseClient.engines is not None:
            return
        DatabaseClient.engines = {}
        DatabaseClient.pool_size = pool_size

    @staticmethod
    def get_session(url: str, timeout: int = 30, echo: bool = False, **configs):
        """
        Return database session

        :param url: str, database url, format as "dialect+driver://username:password@host:port/database"
        :param timeout: int, default value: 30 seconds
        :param echo: bool, default value: False
        :param configs: other configurations
        :return: SQLAlchemy session
        """
        _acquire_lock()
        if url in DatabaseClient.engines:
            engine = DatabaseClient.engines[url]
        else:
            logger.debug("DatabaseSession create new engine, config: {config}".format(config=configs))
            engine = create_engine(url, pool_size=DatabaseClient.pool_size, echo=echo, pool_timeout=timeout, **configs)
            DatabaseClient.engines[url] = engine
        _release_lock()
        return sessionmaker(bind=engine)()

    def __init__(self, url: str, timeout: int = 30, echo: bool = False, **configs):
        """
        Create database session

        :param url: str, database url, format as "dialect+driver://username:password@host:port/database"
        :param timeout: int, default value: 30 seconds
        :param echo: bool, default value: False
        :param configs: other configurations
        """
        if DatabaseClient.engines is None:
            DatabaseClient.init()
        self.session = DatabaseClient.get_session(url=url, timeout=timeout, echo=echo, **configs)

    def execute(self, sqls: list):
        """
        Execute several SQLs

        :param sqls: list, sqls to be executed
        """
        try:
            for sql, param_dict in sqls:
                logger.debug("executing param_dict: {param_dict}".format(param_dict=param_dict))
                logger.debug("executing sql: {sql}".format(sql=sql))
                self.session.execute(text(sql), param_dict)
            self.session.commit()
        except Exception as e:
            logger.error(e)
            raise DBException("cannot update status: {exception}".format(exception=e))

    def get_values(self, sql: str, param_dict: dict) -> list:
        """
        Get values from database

        :param sql: str
        :param param_dict: dict
        :return: list, values
        """
        logger.debug("executing param_dict: {param_dict}".format(param_dict=param_dict))
        logger.debug("executing sql: {sql}".format(sql=sql))
        try:
            result = self.session.execute(text(sql), param_dict)
            rows = result.fetchall()
            return rows
        except Exception as e:
            logger.error(e)
            raise DBException("cannot get values: {exception}".format(exception=e))

    def get_value(self, sql: str, param_dict: dict) -> tuple:
        """
        Get value from database

        :param sql: str
        :param param_dict: dict
        :return: tuple, values
        """
        logger.debug("executing param_dict: {param_dict}".format(param_dict=param_dict))
        logger.debug("executing sql: {sql}".format(sql=sql))
        try:
            result = self.session.execute(text(sql), param_dict)
            row = result.fetchone()
            return row
        except Exception as e:
            logger.error(e)
            raise DBException("cannot get values: {exception}".format(exception=e))

    def close(self):
        """Close database session
        """
        try:
            self.session.close()
        except Exception as e:
            logger.error(e)
            raise DBException("cannot close: {exception}".format(exception=e))


if __name__ == '__main__':
    conn = DatabaseClient(
        "postgresql+psycopg2://xingqiao:Yhth111#@pgm-2zes4j7rsv2xbv789o.pg.rds.aliyuncs.com:1921/winhye_test"
    )
    conn.init(pool_size=1)
    sql = "select robot_id, video_stream from robot_info"
    res = conn.get_values(sql, {})
    logger.info(res)
    conn.close()



import os
import logging
import socket
import flask

# get ip address
s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
s.connect(('8.8.8.8', 53))
ip = s.getsockname()[0]
s.close()

# gunicorn worker class
worker_class = os.environ.get("GUNICORN_WORKER_CLASS", "sync")


class HostAddressFilter(logging.Filter):
    """Add host address to logging.format
    """

    def filter(self, record):
        if "HOSTNAME" in os.environ:
            record.hostname = os.environ.get("HOSTNAME")
            return True
        record.hostname = ip
        return True


class RequestAddressFilter(logging.Filter):
    """Add request address to logging.format, "127.0.0.1" for non-flask scenario
    """

    def filter(self, record):
        try:
            if flask.request.headers.getlist("X-Forwarded-For"):
                source_ip = flask.request.headers.getlist("X-Forwarded-For")[0]
            else:
                source_ip = flask.request.remote_addr
        except:
            # not in Flask scope
            source_ip = "127.0.0.1"
        record.source_ip = source_ip
        return True


class ConcurrentIdFilter(logging.Filter):
    """Add concurrent id to logging.format
    """

    def filter(self, record):
        from threading import get_ident
        concurrent_id = get_ident()
        record.concurrent_id = concurrent_id
        return True



import json
import os

__all__ = ["config"]


class Config:
    def __init__(self):
        idc = os.environ.get('IDC')
        config_path = os.path.join(os.path.dirname(__file__), "config.json")
        with open(config_path, "r") as f:
            config_all = json.loads(f.read())
        if idc:
            self.config = config_all[idc]
        else:
            self.config = config_all["test"]

    def get_pg_config(self):
        return self.config["pg_config"]

    def get_oss_config(self):
        return self.config["oss_config"]

    def get_mqtt_config(self):
        return self.config["mqtt_config"]

    def get_app_config(self):
        return self.config["app"]

    def get_websocket_config(self):
        return self.config["websocket_config"]

    def get_auth_video_config(self):
        return self.config["auth_video_config"]

    def get_invite_code_overdue_time(self):
        return self.config["invite_code_overdue_time"]

    def get_province_abbreviation(self):
        return self.config["province_abbreviation"]


config = Config()



import os
import sys

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "src")
sys.path.append(PATH)


from winhye_common.utils import CookieRsa


def test_ras():
    obj = CookieRsa()
    # encrypt = obj.rsa_encrypt('text')
    decrypt = obj.rsa_decrypt("test")
    # print(encrypt)
    print(decrypt)


if __name__ == '__main__':
    test_ras()



import os
import sys
import time

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "src")
sys.path.append(PATH)
print(PATH)

from winhye_common.winhye_logger import logging as logging


def log_test():
    logger = logging.getLogger()
    for i in range(10000):
        logger.info("1111111111111111")
        time.sleep(1)


def log_test2():
    logger = logging.getLogger()
    logger.report("123456")


if __name__ == '__main__':
    log_test2()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="winhye-common",
    version="0.0.4",
    author="千城",
    author_email="qiancheng0402@163.com",
    description="public package including ES, logging, oss, db...",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://e.gitee.com/winhye998/repos/winhye998/winhye-common",
    project_urls={},
    classifiers=[
        "Programming Language :: Python :: 3.6",
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=[
        "flask",
        "paho-mqtt",
        "websocket-server",
        "sqlalchemy",
        "psycopg2",
        "oss2",
        "crypto"
    ]
)



import os
import sys

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "src")
sys.path.append(PATH)
print(PATH)

from winhye_common.session.database import DatabaseClient


def test_database():
    conn = DatabaseClient(
        "postgresql+psycopg2://xingqiao:Yhth111#@pgm-2zes4j7rsv2xbv789o.pg.rds.aliyuncs.com:1921/winhye_pre")
    sql = "select * from user_info;"
    res = conn.get_values(sql, {})
    print(res)
    conn.close()


if __name__ == '__main__':
    test_database()



import enum

__all__ = ["ExceptionCode", "WinhyeException"]


# exception codes
class ExceptionCode(enum.Enum):
    DB = 1
    OSS = 2
    mqtt = 3


class WinhyeException(Exception):
    def __init__(self, code: ExceptionCode, message: str):
        self.code = code.value
        self.message = message

    def __str__(self):
        return "{exception}: winhye-common error code={code}, message={message}".format(
            exception=self.__class__.__name__,
            code=self.code,
            message=self.message
        )
